@@ -15,32 +15,21 @@
 # You should have received a copy of the GNU General Public License
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
-import pkg_resources
-
-PROGRAM_NAME = 'ocrmypdf'
-
-# Official PEP 396
-__version__ = pkg_resources.get_distribution('ocrmypdf').version
-
-VERSION = __version__
-
+from . import helpers, hocrtransform, leptonica, pdfa, pdfinfo
+from ._version import PROGRAM_NAME, __version__
+from .api import Verbosity, configure_logging, ocr
 from .exceptions import (
-    ExitCode,
     BadArgsError,
-    PdfMergeFailedError,
-    MissingDependencyError,
-    UnsupportedImageFormatError,
     DpiError,
-    OutputFileAccessError,
-    PriorOcrFoundError,
-    InputFileError,
-    SubprocessOutputError,
     EncryptedPdfError,
+    ExitCode,
+    ExitCodeException,
+    InputFileError,
+    MissingDependencyError,
+    OutputFileAccessError,
+    PdfMergeFailedError,
+    PriorOcrFoundError,
+    SubprocessOutputError,
     TesseractConfigError,
+    UnsupportedImageFormatError,
 )
-
-from . import helpers
-from . import hocrtransform
-from . import leptonica
-from . import pdfa
-from . import pdfinfo
