@@ -17,6 +17,7 @@
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
 
+import locale
 import logging
 import os
 import sys
@@ -41,12 +42,13 @@ from .exec import (
     tesseract,
     unpaper,
 )
-from .helpers import is_file_writable, is_iterable_notstr, monotonic, re_symlink
+from .helpers import is_file_writable, is_iterable_notstr, monotonic, safe_symlink
 
 # -------------
 # External dependencies
 
 HOCR_OK_LANGS = frozenset(['eng', 'deu', 'spa', 'ita', 'por'])
+DEFAULT_LANGUAGE = 'eng'  # Enforce English hegemony
 
 log = logging.getLogger(__name__)
 
@@ -56,9 +58,21 @@ log = logging.getLogger(__name__)
 verify_python3_env()
 
 
+def check_platform():
+    if os.name == 'nt' and sys.maxsize <= 2 ** 32:  # pragma: no cover
+        # 32-bit interpreter on Windows
+        log.error(
+            "You are running OCRmyPDF in a 32-bit (x86) Python interpreter."
+            "Please use a 64-bit (x86-64) version of Python."
+        )
+
+
 def check_options_languages(options):
     if not options.language:
-        options.language = ['eng']  # Enforce English hegemony
+        options.language = [DEFAULT_LANGUAGE]
+        system_lang = locale.getlocale()[0]
+        if system_lang and not system_lang.startswith('en'):
+            log.debug("No language specified; assuming --language %s", DEFAULT_LANGUAGE)
 
     # Support v2.x "eng+deu" language syntax
     if '+' in options.language[0]:
@@ -287,6 +301,7 @@ def check_options_pillow(options):
 
 
 def check_options(options):
+    check_platform()
     check_options_languages(options)
     check_options_metadata(options)
     check_options_output(options)
@@ -299,7 +314,7 @@ def check_options(options):
     check_dependency_versions(options)
 
 
-def check_closed_streams(options):
+def check_closed_streams(options):  # pragma: no cover
     """Work around Python issue with multiprocessing forking on closed streams
 
     https://bugs.python.org/issue28326
@@ -365,12 +380,12 @@ def create_input_file(options, work_folder):
         target = os.path.join(work_folder, 'stdin')
         with open(target, 'wb') as stream_buffer:
             copyfileobj(sys.stdin.buffer, stream_buffer)
-        return target
+        return target, "<stdin>"
     else:
         try:
             target = os.path.join(work_folder, 'origin')
-            re_symlink(options.input_file, target)
-            return target
+            safe_symlink(options.input_file, target)
+            return target, os.fspath(options.input_file)
         except FileNotFoundError:
             raise InputFileError(f"File not found - {options.input_file}")
 
@@ -413,6 +428,20 @@ def report_output_file_size(options, input_file, output_file):
                 f"The argument --{arg.replace('_', '-')} was issued, causing transcoding."
             )
 
+    if options.optimize == 0:
+        reasons.append("Optimization was disabled.")
+    else:
+        image_optimizers = {
+            'jbig2': jbig2enc.available(),
+            'pngquant': pngquant.available(),
+        }
+        for name, available in image_optimizers.items():
+            if not available:
+                reasons.append(
+                    f"The optional dependency '{name}' was not found, so some image "
+                    f"optimizations could not be attempted."
+                )
+
     if reasons:
         explanation = "Possible reasons for this include:\n" + '\n'.join(reasons) + "\n"
     else:
@@ -427,7 +456,7 @@ def report_output_file_size(options, input_file, output_file):
 def check_dependency_versions(options):
     check_external_program(
         program='tesseract',
-        package={'darwin': 'tesseract', 'linux': 'tesseract-ocr'},
+        package={'linux': 'tesseract-ocr'},
         version_checker=tesseract.version,
         need_version='4.0.0',  # using backport for Travis CI
     )
