@@ -15,25 +15,51 @@
 # You should have received a copy of the GNU General Public License
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
+"""Interface to Ghostscript executable"""
+
 import logging
+import os
 import re
+import warnings
+from contextlib import suppress
 from functools import lru_cache
+from io import BytesIO
 from os import fspath
-from shutil import copy
-from subprocess import PIPE, STDOUT, run
-from tempfile import NamedTemporaryFile
+from pathlib import Path
+from shutil import which
+from subprocess import PIPE, CalledProcessError
 
 from PIL import Image
 
-from ..exceptions import SubprocessOutputError
-from . import get_version
+from ..exceptions import MissingDependencyError, SubprocessOutputError
+from . import get_version, run
 
 gslog = logging.getLogger()
 
+GS = 'gs'
+if os.name == 'nt':
+    GS = which('gswin64c')
+    if not GS:
+        GS = which('gswin32c')
+        if not GS:
+            raise MissingDependencyError(
+                """
+                ---------------------------------------------------------------------
+                This error normally occurs when ocrmypdf can't Ghostscript.  Please
+                ensure Ghostscript is installed and its location is added to the
+                system PATH environment variable.
+
+                For details see:
+                    https://ocrmypdf.readthedocs.io/en/latest/installation.html
+                ---------------------------------------------------------------------
+                """
+            )
+    GS = Path(GS).stem
+
 
 @lru_cache(maxsize=1)
 def version():
-    return get_version('gs')
+    return get_version(GS)
 
 
 def jpeg_passthrough_available():
@@ -78,9 +104,12 @@ def extract_text(input_file, pageno=1):
     else:
         pages = []
 
+    # Note due to bug https://bugs.ghostscript.com/show_bug.cgi?id=701971
+    # Ghostscript <= 9.50 will truncate output unless we write to stdout, so
+    # don't write to a file.
     args_gs = (
         [
-            'gs',
+            GS,
             '-dQUIET',
             '-dSAFER',
             '-dBATCH',
@@ -89,14 +118,15 @@ def extract_text(input_file, pageno=1):
             '-dTextFormat=0',
         ]
         + pages
-        + ['-o', '-', fspath(input_file)]
+        + ['-o', '-', fspath(input_file), "-sstdout=%stderr"]
     )
 
-    p = run(args_gs, stdout=PIPE, stderr=PIPE)
-    if p.returncode != 0:
+    try:
+        p = run(args_gs, stdout=PIPE, stderr=PIPE, check=True)
+    except CalledProcessError as e:
         raise SubprocessOutputError(
-            'Ghostscript text extraction failed\n%s\n%s\n%s'
-            % (input_file, p.stdout.decode(), p.stderr.decode())
+            'Ghostscript text extraction failed\n%s\n%s'
+            % (input_file, e.stderr.decode(errors='replace'))
         )
 
     return p.stdout
@@ -138,54 +168,56 @@ def rasterize_pdf(
     if not log:
         log = gslog
 
-    with NamedTemporaryFile(delete=True) as tmp:
-        args_gs = (
-            [
-                'gs',
-                '-dQUIET',
-                '-dSAFER',
-                '-dBATCH',
-                '-dNOPAUSE',
-                f'-sDEVICE={raster_device}',
-                f'-dFirstPage={pageno}',
-                f'-dLastPage={pageno}',
-                f'-r{res[0]:f}x{res[1]:f}',
-            ]
-            + (['-dFILTERVECTOR'] if filter_vector else [])
-            + [
-                '-o',
-                tmp.name,
-                '-dAutoRotatePages=/None',  # Probably has no effect on raster
-                '-f',
-                fspath(input_file),
-            ]
-        )
+    args_gs = (
+        [
+            GS,
+            '-dQUIET',
+            '-dSAFER',
+            '-dBATCH',
+            '-dNOPAUSE',
+            f'-sDEVICE={raster_device}',
+            f'-dFirstPage={pageno}',
+            f'-dLastPage={pageno}',
+            f'-r{res[0]:f}x{res[1]:f}',
+        ]
+        + (['-dFILTERVECTOR'] if filter_vector else [])
+        + [
+            '-o',
+            '-',
+            '-sstdout=%stderr',
+            '-dAutoRotatePages=/None',  # Probably has no effect on raster
+            '-f',
+            fspath(input_file),
+        ]
+    )
 
-        log.debug(args_gs)
-        p = run(args_gs, stdout=PIPE, stderr=STDOUT, universal_newlines=True)
-        if _gs_error_reported(p.stdout):
-            log.error(p.stdout)
-        elif p.stdout:
-            log.debug(p.stdout)
+    log.debug(args_gs)
+    try:
+        p = run(args_gs, stdout=PIPE, stderr=PIPE, check=True)
+    except CalledProcessError as e:
+        log.error(e.stderr.decode(errors='replace'))
+        raise SubprocessOutputError('Ghostscript rasterizing failed')
+    else:
+        stderr = p.stderr.decode(errors='replace')
+        if _gs_error_reported(stderr):
+            log.error(stderr)
+        elif stderr:
+            log.debug(stderr)
 
-        if p.returncode != 0:
-            raise SubprocessOutputError('Ghostscript rasterizing failed')
-
-        tmp.seek(0)
-        with Image.open(tmp) as im:
-            if rotation is not None:
-                log.debug("Rotating output by %i", rotation)
-                # rotation is a clockwise angle and Image.ROTATE_* is
-                # counterclockwise so this cancels out the rotation
-                if rotation == 90:
-                    im = im.transpose(Image.ROTATE_90)
-                elif rotation == 180:
-                    im = im.transpose(Image.ROTATE_180)
-                elif rotation == 270:
-                    im = im.transpose(Image.ROTATE_270)
-                if rotation % 180 == 90:
-                    page_dpi = page_dpi[1], page_dpi[0]
-            im.save(fspath(output_file), dpi=page_dpi)
+    with Image.open(BytesIO(p.stdout)) as im:
+        if rotation is not None:
+            log.debug("Rotating output by %i", rotation)
+            # rotation is a clockwise angle and Image.ROTATE_* is
+            # counterclockwise so this cancels out the rotation
+            if rotation == 90:
+                im = im.transpose(Image.ROTATE_90)
+            elif rotation == 180:
+                im = im.transpose(Image.ROTATE_180)
+            elif rotation == 270:
+                im = im.transpose(Image.ROTATE_270)
+            if rotation % 180 == 90:
+                page_dpi = page_dpi[1], page_dpi[0]
+        im.save(fspath(output_file), dpi=page_dpi)
 
 
 def generate_pdfa(
@@ -193,7 +225,7 @@ def generate_pdfa(
     output_file,
     compression,
     log,
-    threads=1,
+    threads=None,  # deprecated parameter
     pdf_version='1.5',
     pdfa_part='2',
 ):
@@ -216,6 +248,10 @@ def generate_pdfa(
     """
     if not log:
         log = gslog
+    if threads is not None:
+        warnings.warn(
+            "use of deprecated parameter 'threads'", category=DeprecationWarning
+        )
 
     compression_args = []
     if compression == 'jpeg':
@@ -249,37 +285,55 @@ def generate_pdfa(
         # https://bugs.ghostscript.com/show_bug.cgi?id=699216
         compression_args.append('-dPassThroughJPEGImages=false')
 
-    with NamedTemporaryFile(delete=True) as gs_pdf:
-        # nb no need to specify ProcessColorModel when ColorConversionStrategy
-        # is set; see:
-        # https://bugs.ghostscript.com/show_bug.cgi?id=699392
-        args_gs = (
-            [
-                "gs",
-                "-dQUIET",
-                "-dBATCH",
-                "-dNOPAUSE",
-                "-dSAFER",
-                "-dCompatibilityLevel=" + str(pdf_version),
-                "-sDEVICE=pdfwrite",
-                "-dAutoRotatePages=/None",
-                "-sColorConversionStrategy=" + strategy,
-            ]
-            + compression_args
-            + [
-                "-dJPEGQ=95",
-                "-dPDFA=" + pdfa_part,
-                "-dPDFACompatibilityPolicy=1",
-                "-sOutputFile=" + gs_pdf.name,
-            ]
-        )
-        args_gs.extend(fspath(s) for s in pdf_pages)  # Stringify Path objs
-        log.debug(args_gs)
-        p = run(args_gs, stdout=PIPE, stderr=STDOUT, universal_newlines=True)
-
-        if _gs_error_reported(p.stdout):
-            log.error(p.stdout)
-        elif 'overprint mode not set' in p.stdout:
+    # nb no need to specify ProcessColorModel when ColorConversionStrategy
+    # is set; see:
+    # https://bugs.ghostscript.com/show_bug.cgi?id=699392
+    args_gs = (
+        [
+            GS,
+            "-dQUIET",
+            "-dBATCH",
+            "-dNOPAUSE",
+            "-dSAFER",
+            "-dCompatibilityLevel=" + str(pdf_version),
+            "-sDEVICE=pdfwrite",
+            "-dAutoRotatePages=/None",
+            "-sColorConversionStrategy=" + strategy,
+        ]
+        + compression_args
+        + [
+            "-dJPEGQ=95",
+            "-dPDFA=" + pdfa_part,
+            "-dPDFACompatibilityPolicy=1",
+            "-o",
+            "-",
+            "-sstdout=%stderr",
+        ]
+    )
+    args_gs.extend(fspath(s) for s in pdf_pages)  # Stringify Path objs
+    try:
+        with Path(output_file).open('wb') as output:
+            p = run(args_gs, stdout=output, stderr=PIPE, check=True)
+    except CalledProcessError as e:
+        # Ghostscript does not change return code when it fails to create
+        # PDF/A - check PDF/A status elsewhere
+        log.error(e.stderr.decode(errors='replace'))
+        raise SubprocessOutputError('Ghostscript PDF/A rendering failed')
+    else:
+        stderr = p.stderr.decode('utf-8', errors='replace')
+        if _gs_error_reported(stderr):
+            last_part = None
+            repcount = 0
+            for part in stderr.split('****'):
+                if part != last_part:
+                    if repcount > 1:
+                        log.error(f"(previous error message repeated {repcount} times)")
+                        repcount = 0
+                    log.error(part)
+                else:
+                    repcount += 1
+                last_part = part
+        elif 'overprint mode not set' in stderr:
             # Unless someone is going to print PDF/A documents on a
             # magical sRGB printer I can't see the removal of overprinting
             # being a problem....
@@ -287,12 +341,3 @@ def generate_pdfa(
                 "Ghostscript had to remove PDF 'overprinting' from the "
                 "input file to complete PDF/A conversion. "
             )
-        else:
-            log.debug(p.stdout)
-
-        if p.returncode == 0:
-            # Ghostscript does not change return code when it fails to create
-            # PDF/A - check PDF/A status elsewhere
-            copy(gs_pdf.name, fspath(output_file))
-        else:
-            raise SubprocessOutputError('Ghostscript PDF/A rendering failed')
