@@ -15,11 +15,13 @@
 # You should have received a copy of the GNU General Public License
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
+"""Interface to jbig2 executable"""
+
 from functools import lru_cache
-from subprocess import PIPE, run
+from subprocess import PIPE
 
 from ..exceptions import MissingDependencyError
-from . import get_version
+from . import get_version, run
 
 
 @lru_cache(maxsize=1)
