@@ -15,22 +15,23 @@
 # You should have received a copy of the GNU General Public License
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
+"""Interface to Tesseract executable"""
+
+import logging
 import os
 import shutil
-import sys
 from collections import namedtuple
 from contextlib import suppress
-from functools import lru_cache
 from os import fspath
-from subprocess import PIPE, STDOUT, CalledProcessError, TimeoutExpired, run
+from subprocess import PIPE, STDOUT, CalledProcessError, TimeoutExpired
 
 from ..exceptions import (
     MissingDependencyError,
     SubprocessOutputError,
     TesseractConfigError,
 )
-from ..helpers import page_number
-from . import get_version
+from ..helpers import page_number, safe_symlink
+from . import get_version, run
 
 OrientationConfidence = namedtuple('OrientationConfidence', ('angle', 'confidence'))
 
@@ -52,6 +53,12 @@ HOCR_TEMPLATE = """<?xml version="1.0" encoding="UTF-8"?>
 """
 
 
+class TesseractLoggerAdapter(logging.LoggerAdapter):
+    def process(self, msg, kwargs):
+        kwargs['extra'] = self.extra
+        return '[tesseract] %s' % (msg), kwargs
+
+
 def version(tesseract_env=None):
     return get_version('tesseract', regex=r'tesseract\s(.+)', env=tesseract_env)
 
@@ -121,9 +128,10 @@ def languages(tesseract_env=None):
     except CalledProcessError as e:
         raise MissingDependencyError(lang_error(e.output)) from e
 
+    for line in output.splitlines():
+        if line.startswith('Error'):
+            raise MissingDependencyError(lang_error(output))
     header, *rest = output.splitlines()
-    if not header.startswith('List of available languages'):
-        raise MissingDependencyError(lang_error(output))
     return set(lang.strip() for lang in rest)
 
 
@@ -131,7 +139,7 @@ def tess_base_args(langs, engine_mode):
     args = ['tesseract']
     if langs:
         args.extend(['-l', '+'.join(langs)])
-    if engine_mode is not None and v4():
+    if engine_mode is not None:
         args.extend(['--oem', str(engine_mode)])
     return args
 
@@ -179,19 +187,15 @@ def get_orientation(input_file, engine_mode, timeout: float, log, tesseract_env=
         return oc
 
 
-def tesseract_log_output(log, stdout, input_file):
-    prefix = "[tesseract] "
+def tesseract_log_output(mainlog, stdout, input_file):
+    log = TesseractLoggerAdapter(
+        mainlog, extra=mainlog.extra if hasattr(mainlog, 'extra') else None
+    )
 
     try:
         text = stdout.decode()
     except UnicodeDecodeError:
-        log.error(
-            prefix
-            + "command line output was not utf-8. "
-            + "This usually means Tesseract's language packs do not match "
-            "the installed version of Tesseract."
-        )
-        text = stdout.decode('utf-8', 'backslashreplace')
+        text = stdout.decode('utf-8', 'ignore')
 
     lines = text.splitlines()
     for line in lines:
@@ -200,25 +204,25 @@ def tesseract_log_output(log, stdout, input_file):
         elif line.startswith("Warning in pixReadMem"):
             continue
         elif 'diacritics' in line:
-            log.warning(prefix + "lots of diacritics - possibly poor OCR")
+            log.warning("lots of diacritics - possibly poor OCR")
         elif line.startswith('OSD: Weak margin'):
-            log.warning(prefix + "unsure about page orientation")
+            log.warning("unsure about page orientation")
         elif 'Error in pixScanForForeground' in line:
             pass  # Appears to be spurious/problem with nonwhite borders
         elif 'Error in boxClipToRectangle' in line:
             pass  # Always appears with pixScanForForeground message
         elif 'parameter not found: ' in line.lower():
-            log.error(prefix + line.strip())
+            log.error(line.strip())
             problem = line.split('found: ')[1]
             raise TesseractConfigError(problem)
         elif 'error' in line.lower() or 'exception' in line.lower():
-            log.error(prefix + line.strip())
+            log.error(line.strip())
         elif 'warning' in line.lower():
-            log.warning(prefix + line.strip())
+            log.warning(line.strip())
         elif 'read_params_file' in line.lower():
-            log.error(prefix + line.strip())
+            log.error(line.strip())
         else:
-            log.info(prefix + line.strip())
+            log.info(line.strip())
 
 
 def page_timedout(log, input_file, timeout):
@@ -256,8 +260,8 @@ def generate_hocr(
     log,
 ):
 
-    output_hocr = next(o for o in output_files if o.endswith('.hocr'))
-    output_sidecar = next(o for o in output_files if o.endswith('.txt'))
+    output_hocr = next(o for o in output_files if fspath(o).endswith('.hocr'))
+    output_sidecar = next(o for o in output_files if fspath(o).endswith('.txt'))
     prefix = os.path.splitext(output_hocr)[0]
 
     args_tesseract = tess_base_args(language, engine_mode)
@@ -275,7 +279,6 @@ def generate_hocr(
     # to the number of order parameters here
     args_tesseract.extend([input_file, prefix, 'hocr', 'txt'] + tessconfig)
     try:
-        log.debug(args_tesseract)
         p = run(
             args_tesseract,
             stdout=PIPE,
@@ -314,7 +317,7 @@ def use_skip_page(text_only, skip_pdf, output_pdf, output_text):
         # Substitute a "skipped page"
         with suppress(FileNotFoundError):
             os.remove(output_pdf)  # In case it was partially created
-        os.symlink(skip_pdf, output_pdf)
+        safe_symlink(skip_pdf, output_pdf)
         return
 
     # Or normally, just write a 0 byte file to the output to indicate a skip
@@ -374,7 +377,6 @@ def generate_pdf(
 
     args_tesseract.extend([input_image, prefix, 'pdf', 'txt'] + tessconfig)
     try:
-        log.debug(args_tesseract)
         p = run(
             args_tesseract,
             stdout=PIPE,
