@@ -18,10 +18,10 @@
 # unpaper documentation:
 # https://github.com/Flameeyes/unpaper/blob/master/doc/basic-concepts.md
 
+"""Interface to unpaper executable"""
+
 import os
 import shlex
-import subprocess
-import sys
 from functools import lru_cache
 from subprocess import PIPE, STDOUT, CalledProcessError
 from tempfile import TemporaryDirectory
@@ -30,6 +30,7 @@ from PIL import Image
 
 from ..exceptions import MissingDependencyError, SubprocessOutputError
 from . import get_version
+from . import run as external_run
 
 
 @lru_cache(maxsize=1)
@@ -76,7 +77,7 @@ def run(input_file, output_file, dpi, log, mode_args):
         # their unpaper arguments (whether intentionally or otherwise)
         args_unpaper.extend([input_pnm, output_pnm])
         try:
-            proc = subprocess.run(
+            proc = external_run(
                 args_unpaper,
                 check=True,
                 close_fds=True,
