@@ -18,6 +18,7 @@
 import logging
 import multiprocessing
 import os
+import shutil
 import warnings
 from collections.abc import Iterable
 from contextlib import suppress
@@ -27,14 +28,14 @@ from pathlib import Path
 log = logging.getLogger(__name__)
 
 
-def re_symlink(input_file, soft_link_name, *args, **kwargs):
+def safe_symlink(input_file, soft_link_name, *args, **kwargs):
     """
     Helper function: relinks soft symbolic link if necessary
     """
     if len(args) == 1 and isinstance(args[0], logging.Logger):
-        log.warning("Deprecated: re_symlink(,log)")
+        log.warning("Deprecated: safe_symlink(,log)")
     if 'log' in kwargs:
-        log.warning('Deprecated: re_symlink(...log=)')
+        log.warning('Deprecated: safe_symlink(...log=)')
 
     input_file = os.fspath(input_file)
     soft_link_name = os.fspath(soft_link_name)
@@ -60,6 +61,11 @@ def re_symlink(input_file, soft_link_name, *args, **kwargs):
     if not os.path.exists(input_file):
         raise FileNotFoundError(f"trying to create a broken symlink to {input_file}")
 
+    if os.name == 'nt':
+        # Don't actually use symlinks on Windows due to permission issues
+        shutil.copyfile(input_file, soft_link_name)
+        return
+
     log.debug("os.symlink(%s, %s)", input_file, soft_link_name)
 
     # Create symbolic link using absolute path
@@ -98,28 +104,36 @@ def is_file_writable(test_file):
     can replace it atomically. Before doing the OCR work, make sure
     the location is writable.
     """
-    p = Path(test_file)
-
-    if p.is_symlink():
-        p = p.resolve(strict=False)
-
-    # p.is_file() throws an exception in some cases
-    if p.exists() and p.is_file():
-        return os.access(
-            os.fspath(p),
-            os.W_OK,
-            effective_ids=(os.access in os.supports_effective_ids),
-        )
-    else:
-        try:
-            fp = p.open('wb')
-        except OSError:
-            return False
+    try:
+        if not isinstance(test_file, Path):
+            p = Path(test_file)
         else:
-            fp.close()
-            with suppress(OSError):
-                p.unlink()
-        return True
+            p = test_file
+
+        if p.is_symlink():
+            p = p.resolve(strict=False)
+
+        # p.is_file() throws an exception in some cases
+        if p.exists() and p.is_file():
+            return os.access(
+                os.fspath(p),
+                os.W_OK,
+                effective_ids=(os.access in os.supports_effective_ids),
+            )
+        else:
+            try:
+                fp = p.open('wb')
+            except OSError:
+                return False
+            else:
+                fp.close()
+                with suppress(OSError):
+                    p.unlink()
+            return True
+    except (EnvironmentError, RuntimeError) as e:
+        log.debug(e)
+        log.error(str(e))
+        return False
 
 
 def deprecated(func):
