@@ -33,14 +33,46 @@ from io import BytesIO
 from os import fspath
 from tempfile import TemporaryFile
 
+from .exceptions import MissingDependencyError
+from .exec import shim_paths_with_program_files
 from .lib._leptonica import ffi
 
 # pylint: disable=protected-access
 
 logger = logging.getLogger(__name__)
 
-lept = ffi.dlopen(find_library('lept'))
-lept.setMsgSeverity(lept.L_SEVERITY_WARNING)
+if os.name == 'nt':
+    libname = 'liblept-5'
+    os.environ['PATH'] = shim_paths_with_program_files()
+else:
+    libname = 'lept'
+_libpath = find_library(libname)
+if not _libpath:
+    raise MissingDependencyError(
+        """
+        ---------------------------------------------------------------------
+        This error normally occurs when ocrmypdf can't find the Leptonica
+        library, which is usually installed with Tesseract OCR. It could be that
+        Tesseract is not installed properly, we can't find the installation
+        on your system PATH environment variable.
+
+        The library we are looking for is usually called:
+            liblept-5.dll   (Windows)
+            liblept*.dylib  (macOS)
+            liblept*.so     (Linux/BSD)
+
+        Please review our installation procedures to find a solution:
+            https://ocrmypdf.readthedocs.io/en/latest/installation.html
+        ---------------------------------------------------------------------
+        """
+    )
+try:
+    lept = ffi.dlopen(_libpath)
+    lept.setMsgSeverity(lept.L_SEVERITY_WARNING)
+except ffi.error as e:
+    raise MissingDependencyError(
+        f"Leptonica library found at {_libpath}, but we could not access it"
+    ) from e
 
 
 class _LeptonicaErrorTrap:
@@ -292,9 +324,11 @@ class Pix(LeptonicaObject):
         Leptonica can load TIFF, PNM (PBM, PGM, PPM), PNG, and JPEG.  If
         loading fails then the object will wrap a C null pointer.
         """
-        filename = fspath(path)
-        with _LeptonicaErrorTrap():
-            return cls(lept.pixRead(os.fsencode(filename)))
+        with open(path, 'rb') as py_file:
+            data = py_file.read()
+            buffer = ffi.from_buffer(data)
+            with _LeptonicaErrorTrap():
+                return cls(lept.pixReadMem(buffer, len(buffer)))
 
     def write_implied_format(self, path, jpeg_quality=0, jpeg_progressive=0):
         """Write pix to the filename, with the extension indicating format.
@@ -302,11 +336,19 @@ class Pix(LeptonicaObject):
         jpeg_quality -- quality (iff JPEG; 1 - 100, 0 for default)
         jpeg_progressive -- (iff JPEG; 0 for baseline seq., 1 for progressive)
         """
-        filename = fspath(path)
-        with _LeptonicaErrorTrap():
-            lept.pixWriteImpliedFormat(
-                os.fsencode(filename), self._cdata, jpeg_quality, jpeg_progressive
-            )
+        lept_format = lept.getImpliedFileFormat(os.fsencode(path))
+        with open(path, 'wb') as py_file:
+            data = ffi.new('l_uint8 **pdata')
+            size = ffi.new('size_t *psize')
+            with _LeptonicaErrorTrap():
+                if lept_format == lept.L_JPEG_ENCODE:
+                    lept.pixWriteMemJpeg(
+                        data, size, self._cdata, jpeg_quality, jpeg_progressive
+                    )
+                else:
+                    lept.pixWriteMem(data, size, self._cdata, lept_format)
+            buffer = ffi.buffer(data[0], size[0])
+            py_file.write(buffer)
 
     @classmethod
     def frompil(self, pillow_image):
@@ -502,17 +544,14 @@ class Pix(LeptonicaObject):
         display=0,
         pdfdir=ffi.NULL,
     ):
+        if get_leptonica_version() < 'leptonica-1.76':
+            # Leptonica 1.76 changed the API for pixFindPageForeground; we don't
+            # support the old version
+            raise LeptonicaError("Not available in this version of Leptonica")
         with _LeptonicaErrorTrap():
             cropbox = Box(
                 lept.pixFindPageForeground(
-                    self._cdata,
-                    threshold,
-                    mindist,
-                    erasedist,
-                    pagenum,
-                    showmorph,
-                    display,
-                    pdfdir,
+                    self._cdata, threshold, mindist, erasedist, showmorph, ffi.NULL
                 )
             )
 
