@@ -31,7 +31,7 @@ from . import leptonica
 from ._jobcontext import PDFContext
 from .exceptions import OutputFileAccessError
 from .exec import jbig2enc, pngquant
-from .helpers import re_symlink
+from .helpers import safe_symlink
 
 DEFAULT_JPEG_QUALITY = 75
 DEFAULT_PNG_QUALITY = 70
@@ -111,6 +111,11 @@ def extract_image_generic(*, pike, root, log, image, xref, options):
     if pim.bits_per_component == 1:
         return None
 
+    try:
+        pim.indexed  # pikepdf 1.6.3 can't handle [/Indexed [/Array...]]
+    except NotImplementedError:
+        return None
+
     if filtdp[0] == Name.DCTDecode and options.optimize >= 2:
         # This is a simple heuristic derived from some training data, that has
         # about a 70% chance of guessing whether the JPEG is high quality,
@@ -487,7 +492,7 @@ def optimize(input_file, output_file, context, save_settings):
     log = context.log
     options = context.options
     if options.optimize == 0:
-        re_symlink(input_file, output_file)
+        safe_symlink(input_file, output_file)
         return
 
     if options.jpeg_quality == 0:
@@ -533,7 +538,7 @@ def optimize(input_file, output_file, context, save_settings):
             pike.remove_unreferenced_resources()
             pike.save(output_file, **save_settings)
     else:
-        re_symlink(target_file, output_file)
+        safe_symlink(target_file, output_file)
 
 
 def main(infile, outfile, level, jobs=1):
@@ -544,11 +549,11 @@ def main(infile, outfile, level, jobs=1):
         """Emulate ocrmypdf's options"""
 
         def __init__(
-            self, input_file, jobs, optimize, jpeg_quality, png_quality, jb2lossy
+            self, input_file, jobs, optimize_, jpeg_quality, png_quality, jb2lossy
         ):
             self.input_file = input_file
             self.jobs = jobs
-            self.optimize = optimize
+            self.optimize = optimize_
             self.jpeg_quality = jpeg_quality
             self.png_quality = png_quality
             self.jbig2_page_group_size = 0
@@ -559,7 +564,7 @@ def main(infile, outfile, level, jobs=1):
     options = OptimizeOptions(
         input_file=infile,
         jobs=jobs,
-        optimize=int(level),
+        optimize_=int(level),
         jpeg_quality=0,  # Use default
         png_quality=0,
         jb2lossy=False,
