@@ -32,8 +32,6 @@ Ghostscript's handling of pdfmark.
 """
 
 import base64
-import os
-from binascii import hexlify
 from pathlib import Path
 from string import Template
 
@@ -54,18 +52,7 @@ pdfa_def_template = u"""%!
 def
 
 [/_objdef {icc_PDFA} /type /stream /OBJ pdfmark
-[{icc_PDFA}
-<<
-  /N currentpagedevice /ProcessColorModel known {
-    currentpagedevice /ProcessColorModel get dup /DeviceGray eq
-    {pop 1} {
-      /DeviceRGB eq
-      {3}{4} ifelse
-    } ifelse
-  } {
-    (ERROR, unable to determine ProcessColorModel) == flush
-  } ifelse
->> /PUT pdfmark
+[{icc_PDFA} << /N 3 >> /PUT pdfmark
 [{icc_PDFA} ICCProfile /PUT pdfmark
 
 % Define the output intent dictionary :
@@ -95,8 +82,6 @@ def generate_pdfa_ps(target_filename, icc='sRGB'):
 
     :param target_filename: filename to save
     :param icc: ICC identifier such as 'sRGB'
-
-    :returns: a string containing the entire pdfmark
     """
     if icc == 'sRGB':
         icc_profile = SRGB_ICC_PROFILE
@@ -114,6 +99,7 @@ def generate_pdfa_ps(target_filename, icc='sRGB'):
     # We should have encoded everything to pure ASCII by this point, and
     # to be safe, only allow ASCII in PostScript
     Path(target_filename).write_text(ps, encoding='ascii')
+    return target_filename
 
 
 def file_claims_pdfa(filename):
