@@ -25,23 +25,17 @@ import os
 import sys
 from subprocess import check_call
 
+from gs import real_ghostscript
 
 """Replicate one type of Ghostscript feature elision warning during
 PDF/A creation."""
 
 
-def real_ghostscript(argv):
-    gs_args = ['gs'] + argv[1:]
-    os.execvp("gs", gs_args)
-    return  # Not reachable
-
-
 elision_warning = """GPL Ghostscript 9.20: Setting Overprint Mode to 1
 not permitted in PDF/A-2, overprint mode not set"""
 
 
 def main():
-    os.environ['PATH'] = os.environ['_OCRMYPDF_SAVE_PATH']
     if '--version' in sys.argv:
         print('9.20')
         print('SPOOFED: ' + os.path.basename(__file__))
