@@ -23,19 +23,14 @@
 import os
 import sys
 
+from gs import real_ghostscript
+
 
 """Replicate Ghostscript PDF/A conversion failure by suppressing some
 arguments"""
 
 
-def real_ghostscript(argv):
-    gs_args = ['gs'] + argv[1:]
-    os.execvp("gs", gs_args)
-    return  # Not reachable
-
-
 def main():
-    os.environ['PATH'] = os.environ['_OCRMYPDF_SAVE_PATH']
     if '--version' in sys.argv:
         print('9.20')
         print('SPOOFED: ' + os.path.basename(__file__))
