@@ -24,29 +24,24 @@
 import os
 import sys
 
+from gs import real_ghostscript
+
 """Replicate Ghostscript raster failure while allowing rendering"""
 
 
-def real_ghostscript(argv):
-    gs_args = ['gs'] + argv[1:]
-    os.execvp("gs", gs_args)
-    return  # Not reachable
-
-
 def main():
-    os.environ['PATH'] = os.environ['_OCRMYPDF_SAVE_PATH']
     if '--version' in sys.argv:
         print('9.20')
         print('SPOOFED: ' + os.path.basename(__file__))
         sys.exit(0)
 
-    # For any rendering calls (device == pdfwrite) call real ghostscript
-    if '-sDEVICE=pdfwrite' in sys.argv:
+    # For non-image rastering calls, use real ghostscript
+    if '-sDEVICE=pdfwrite' in sys.argv or '-sDEVICE=txtwrite' in sys.argv:
         real_ghostscript(sys.argv)
         return
 
     # Fail
-    print("ERROR: Ghost story archive not found")
+    print("ERROR: Ghost story archive not found", file=sys.stderr)
     sys.exit(1)
 
 
