@@ -15,22 +15,21 @@
 # You should have received a copy of the GNU General Public License
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
-import logging
 import os
 import shutil
 from math import isclose
 from pathlib import Path
 from subprocess import PIPE, run
+from unittest.mock import patch
 
+import pikepdf
 import PIL
 import pytest
 from PIL import Image
 
 import ocrmypdf
-import pikepdf
 from ocrmypdf.exceptions import ExitCode, MissingDependencyError
 from ocrmypdf.exec import ghostscript, qpdf, tesseract
-from ocrmypdf.leptonica import Pix
 from ocrmypdf.pdfa import file_claims_pdfa
 from ocrmypdf.pdfinfo import Colorspace, Encoding, PdfInfo
 
@@ -39,144 +38,27 @@ from ocrmypdf.pdfinfo import Colorspace, Encoding, PdfInfo
 
 check_ocrmypdf = pytest.helpers.check_ocrmypdf
 run_ocrmypdf = pytest.helpers.run_ocrmypdf
+run_ocrmypdf_api = pytest.helpers.run_ocrmypdf_api
 spoof = pytest.helpers.spoof
 
 
 RENDERERS = ['hocr', 'sandwich']
 
 
-@pytest.fixture(scope='session')
+@pytest.fixture
 def spoof_tesseract_crash(tmp_path_factory):
     return spoof(tmp_path_factory, tesseract='tesseract_crash.py')
 
 
-@pytest.fixture(scope='session')
+@pytest.fixture
 def spoof_tesseract_big_image_error(tmp_path_factory):
     return spoof(tmp_path_factory, tesseract='tesseract_big_image_error.py')
 
 
-@pytest.fixture(scope='session')
-def spoof_no_tess_no_pdfa(tmp_path_factory):
-    return spoof(
-        tmp_path_factory, tesseract='tesseract_noop.py', gs='gs_pdfa_failure.py'
-    )
-
-
-@pytest.fixture(scope='session')
-def spoof_no_tess_pdfa_warning(tmp_path_factory):
-    return spoof(
-        tmp_path_factory, tesseract='tesseract_noop.py', gs='gs_feature_elision.py'
-    )
-
-
-@pytest.fixture(scope='session')
-def spoof_no_tess_gs_render_fail(tmp_path_factory):
-    return spoof(
-        tmp_path_factory, tesseract='tesseract_noop.py', gs='gs_render_failure.py'
-    )
-
-
-@pytest.fixture(scope='session')
-def spoof_no_tess_gs_raster_fail(tmp_path_factory):
-    return spoof(
-        tmp_path_factory, tesseract='tesseract_noop.py', gs='gs_raster_failure.py'
-    )
-
-
 def test_quick(spoof_tesseract_cache, resources, outpdf):
     check_ocrmypdf(resources / 'ccitt.pdf', outpdf, env=spoof_tesseract_cache)
 
 
-def test_deskew(spoof_tesseract_noop, resources, outdir):
-    # Run with deskew
-    deskewed_pdf = check_ocrmypdf(
-        resources / 'skew.pdf', outdir / 'skew.pdf', '-d', env=spoof_tesseract_noop
-    )
-
-    # Now render as an image again and use Leptonica to find the skew angle
-    # to confirm that it was deskewed
-    log = logging.getLogger()
-
-    deskewed_png = outdir / 'deskewed.png'
-
-    ghostscript.rasterize_pdf(
-        deskewed_pdf,
-        deskewed_png,
-        xres=150,
-        yres=150,
-        raster_device='pngmono',
-        log=log,
-        pageno=1,
-    )
-
-    pix = Pix.open(deskewed_png)
-    skew_angle, _skew_confidence = pix.find_skew()
-
-    print(skew_angle)
-    assert -0.5 < skew_angle < 0.5, "Deskewing failed"
-
-
-def test_remove_background(spoof_tesseract_noop, resources, outdir):
-    # Ensure the input image does not contain pure white/black
-    with Image.open(resources / 'congress.jpg') as im:
-        assert im.getextrema() != ((0, 255), (0, 255), (0, 255))
-
-    output_pdf = check_ocrmypdf(
-        resources / 'congress.jpg',
-        outdir / 'test_remove_bg.pdf',
-        '--remove-background',
-        '--image-dpi',
-        '150',
-        env=spoof_tesseract_noop,
-    )
-
-    log = logging.getLogger()
-
-    output_png = outdir / 'remove_bg.png'
-
-    ghostscript.rasterize_pdf(
-        output_pdf,
-        output_png,
-        xres=100,
-        yres=100,
-        raster_device='png16m',
-        log=log,
-        pageno=1,
-    )
-
-    # The output image should contain pure white and black
-    with Image.open(output_png) as im:
-        assert im.getextrema() == ((0, 255), (0, 255), (0, 255))
-
-
-# This will run 5 * 2 * 2 = 20 test cases
-@pytest.mark.parametrize(
-    "pdf", ['palette.pdf', 'cmyk.pdf', 'ccitt.pdf', 'jbig2.pdf', 'lichtenstein.pdf']
-)
-@pytest.mark.parametrize("renderer", ['sandwich', 'hocr'])
-@pytest.mark.parametrize("output_type", ['pdf', 'pdfa'])
-def test_exotic_image(
-    spoof_tesseract_cache, pdf, renderer, output_type, resources, outdir
-):
-    outfile = outdir / f'test_{pdf}_{renderer}.pdf'
-    check_ocrmypdf(
-        resources / pdf,
-        outfile,
-        '-dc' if pytest.helpers.have_unpaper() else '-d',
-        '-v',
-        '1',
-        '--output-type',
-        output_type,
-        '--sidecar',
-        '--skip-text',
-        '--pdf-renderer',
-        renderer,
-        env=spoof_tesseract_cache,
-    )
-
-    assert outfile.with_suffix('.pdf.txt').exists()
-
-
 @pytest.mark.parametrize('renderer', RENDERERS)
 def test_oversample(spoof_tesseract_cache, renderer, resources, outpdf):
     oversampled_pdf = check_ocrmypdf(
@@ -197,8 +79,8 @@ def test_oversample(spoof_tesseract_cache, renderer, resources, outpdf):
 
 
 def test_repeat_ocr(resources, no_outpdf):
-    p, _, _ = run_ocrmypdf(resources / 'graph_ocred.pdf', no_outpdf)
-    assert p.returncode != 0
+    result = run_ocrmypdf_api(resources / 'graph_ocred.pdf', no_outpdf)
+    assert result == ExitCode.already_done_ocr
 
 
 def test_force_ocr(spoof_tesseract_cache, resources, outpdf):
@@ -217,7 +99,7 @@ def test_skip_ocr(spoof_tesseract_cache, resources, outpdf):
     assert pdfinfo[0].has_text
 
 
-def test_redo_ocr(spoof_tesseract_cache, resources, outpdf):
+def test_redo_ocr(resources, outpdf):
     in_ = resources / 'graph_ocred.pdf'
     before = PdfInfo(in_, detailed_page_analysis=True)
     out = outpdf
@@ -300,34 +182,34 @@ def test_maximum_options(
     )
 
 
-def test_tesseract_missing_tessdata(resources, no_outpdf):
+def test_tesseract_missing_tessdata(resources, no_outpdf, tmpdir):
     env = os.environ.copy()
-    env['TESSDATA_PREFIX'] = '/tmp'
+    env['TESSDATA_PREFIX'] = os.fspath(tmpdir)
 
-    p, _, err = run_ocrmypdf(
-        resources / 'graph_ocred.pdf', no_outpdf, '-v', '1', '--skip-text', env=env
+    returncode = run_ocrmypdf_api(
+        resources / 'graph.pdf', no_outpdf, '-v', '1', '--skip-text', env=env
     )
-    assert p.returncode == ExitCode.missing_dependency, err
+    assert returncode == ExitCode.missing_dependency
 
 
 def test_invalid_input_pdf(resources, no_outpdf):
-    p, out, err = run_ocrmypdf(resources / 'invalid.pdf', no_outpdf)
-    assert p.returncode == ExitCode.input_file, err
+    result = run_ocrmypdf_api(resources / 'invalid.pdf', no_outpdf)
+    assert result == ExitCode.input_file
 
 
 def test_blank_input_pdf(resources, outpdf):
-    p, out, err = run_ocrmypdf(resources / 'blank.pdf', outpdf)
-    assert p.returncode == ExitCode.ok
+    result = run_ocrmypdf_api(resources / 'blank.pdf', outpdf)
+    assert result == ExitCode.ok
 
 
 def test_force_ocr_on_pdf_with_no_images(spoof_tesseract_crash, resources, no_outpdf):
     # As a correctness test, make sure that --force-ocr on a PDF with no
     # content still triggers tesseract. If tesseract crashes, then it was
     # called.
-    p, _, err = run_ocrmypdf(
+    p, _, _ = run_ocrmypdf(
         resources / 'blank.pdf', no_outpdf, '--force-ocr', env=spoof_tesseract_crash
     )
-    assert p.returncode == ExitCode.child_process_error, err
+    assert p.returncode == ExitCode.child_process_error
     assert not os.path.exists(no_outpdf)
 
 
@@ -340,27 +222,29 @@ def test_german(spoof_tesseract_cache, resources, outdir):
     # properly. It is fine that we are testing -l deu on a French file because
     # we are exercising the functionality not going for accuracy.
     sidecar = outdir / 'francais.txt'
-    p, out, err = run_ocrmypdf(
-        resources / 'francais.pdf',
-        outdir / 'francais.pdf',
-        '-l',
-        'deu',  # more commonly installed
-        '--sidecar',
-        sidecar,
-        env=spoof_tesseract_cache,
-    )
-    if 'deu' not in tesseract.languages():
-        pytest.xfail(reason="tesseract-deu language pack not installed")
-    assert p.returncode == ExitCode.ok, "Requires tesseract deu language pack"
+    try:
+        check_ocrmypdf(
+            resources / 'francais.pdf',
+            outdir / 'francais.pdf',
+            '-l',
+            'deu',  # more commonly installed
+            '--sidecar',
+            sidecar,
+            env=spoof_tesseract_cache,
+        )
+    except MissingDependencyError:
+        if 'deu' not in tesseract.languages():
+            pytest.xfail(reason="tesseract-deu language pack not installed")
+        raise
 
 
 def test_klingon(resources, outpdf):
-    p, out, err = run_ocrmypdf(resources / 'francais.pdf', outpdf, '-l', 'klz')
+    p, _, _ = run_ocrmypdf(resources / 'francais.pdf', outpdf, '-l', 'klz')
     assert p.returncode == ExitCode.missing_dependency
 
 
 def test_missing_docinfo(spoof_tesseract_noop, resources, outpdf):
-    p, out, err = run_ocrmypdf(
+    result = run_ocrmypdf_api(
         resources / 'missing_docinfo.pdf',
         outpdf,
         '-l',
@@ -368,7 +252,7 @@ def test_missing_docinfo(spoof_tesseract_noop, resources, outpdf):
         '--skip-text',
         env=spoof_tesseract_noop,
     )
-    assert p.returncode == ExitCode.ok, err
+    assert result == ExitCode.ok
 
 
 def test_uppercase_extension(spoof_tesseract_noop, resources, outdir):
@@ -379,24 +263,35 @@ def test_uppercase_extension(spoof_tesseract_noop, resources, outdir):
     )
 
 
-def test_input_file_not_found(no_outpdf):
+def test_input_file_not_found(caplog, no_outpdf):
     input_file = "does not exist.pdf"
-    p, out, err = run_ocrmypdf(input_file, no_outpdf)
-    assert p.returncode == ExitCode.input_file
-    assert input_file in out or input_file in err
+    result = run_ocrmypdf_api(input_file, no_outpdf)
+    assert result == ExitCode.input_file
+    assert input_file in caplog.text
 
 
-def test_input_file_not_a_pdf(no_outpdf):
+@pytest.mark.skipif(os.name == 'nt', reason="chmod")
+def test_input_file_not_readable(caplog, resources, outdir, no_outpdf):
+    input_file = outdir / 'trivial.pdf'
+    shutil.copy(resources / 'trivial.pdf', input_file)
+    input_file.chmod(0o000)
+    result = run_ocrmypdf_api(input_file, no_outpdf)
+    assert result == ExitCode.input_file
+    assert str(input_file) in caplog.text
+
+
+def test_input_file_not_a_pdf(caplog, no_outpdf):
     input_file = __file__  # Try to OCR this file
-    p, out, err = run_ocrmypdf(input_file, no_outpdf)
-    assert p.returncode == ExitCode.input_file
-    assert input_file in out or input_file in err
+    result = run_ocrmypdf_api(input_file, no_outpdf)
+    assert result == ExitCode.input_file
+    if os.name != 'nt':  # name will be mangled with \\'s on nt
+        assert input_file in caplog.text
 
 
-def test_encrypted(resources, no_outpdf):
-    p, out, err = run_ocrmypdf(resources / 'skew-encrypted.pdf', no_outpdf)
-    assert p.returncode == ExitCode.encrypted_pdf
-    assert out.find('encrypted')
+def test_encrypted(resources, caplog, no_outpdf):
+    result = run_ocrmypdf_api(resources / 'skew-encrypted.pdf', no_outpdf)
+    assert result == ExitCode.encrypted_pdf
+    assert 'encryption must be removed' in caplog.text
 
 
 @pytest.mark.parametrize('renderer', RENDERERS)
@@ -415,8 +310,8 @@ def test_pagesegmode(renderer, spoof_tesseract_cache, resources, outpdf):
 
 
 @pytest.mark.parametrize('renderer', RENDERERS)
-def test_tesseract_crash(renderer, spoof_tesseract_crash, resources, no_outpdf):
-    p, out, err = run_ocrmypdf(
+def test_tesseract_crash(renderer, spoof_tesseract_crash, resources, no_outpdf, caplog):
+    p, _, err = run_ocrmypdf(
         resources / 'ccitt.pdf',
         no_outpdf,
         '-v',
@@ -427,7 +322,7 @@ def test_tesseract_crash(renderer, spoof_tesseract_crash, resources, no_outpdf):
     )
     assert p.returncode == ExitCode.child_process_error
     assert not os.path.exists(no_outpdf)
-    assert "ERROR" in err
+    assert "SubprocessOutputError" in err
 
 
 def test_tesseract_crash_autorotate(spoof_tesseract_crash, resources, no_outpdf):
@@ -465,70 +360,6 @@ def test_algo4(resources, spoof_tesseract_noop, outpdf):
     assert p.returncode == ExitCode.encrypted_pdf
 
 
-@pytest.mark.parametrize('renderer', RENDERERS)
-def test_non_square_resolution(renderer, spoof_tesseract_cache, resources, outpdf):
-    # Confirm input image is non-square resolution
-    in_pageinfo = PdfInfo(resources / 'aspect.pdf')
-    assert in_pageinfo[0].xres != in_pageinfo[0].yres
-
-    check_ocrmypdf(
-        resources / 'aspect.pdf',
-        outpdf,
-        '--pdf-renderer',
-        renderer,
-        env=spoof_tesseract_cache,
-    )
-
-    out_pageinfo = PdfInfo(outpdf)
-
-    # Confirm resolution was kept the same
-    assert in_pageinfo[0].xres == out_pageinfo[0].xres
-    assert in_pageinfo[0].yres == out_pageinfo[0].yres
-
-
-@pytest.mark.parametrize('renderer', RENDERERS)
-def test_convert_to_square_resolution(
-    renderer, spoof_tesseract_cache, resources, outpdf
-):
-    # Confirm input image is non-square resolution
-    in_pageinfo = PdfInfo(resources / 'aspect.pdf')
-    assert in_pageinfo[0].xres != in_pageinfo[0].yres
-
-    # --force-ocr requires means forced conversion to square resolution
-    check_ocrmypdf(
-        resources / 'aspect.pdf',
-        outpdf,
-        '--force-ocr',
-        '--pdf-renderer',
-        renderer,
-        env=spoof_tesseract_cache,
-    )
-
-    out_pageinfo = PdfInfo(outpdf)
-
-    in_p0, out_p0 = in_pageinfo[0], out_pageinfo[0]
-
-    # Resolution show now be equal
-    assert out_p0.xres == out_p0.yres
-
-    # Page size should match input page size
-    assert isclose(in_p0.width_inches, out_p0.width_inches)
-    assert isclose(in_p0.height_inches, out_p0.height_inches)
-
-    # Because we rasterized the page to produce a new image, it should occupy
-    # the entire page
-    out_im_w = out_p0.images[0].width / out_p0.images[0].xres
-    out_im_h = out_p0.images[0].height / out_p0.images[0].yres
-    assert isclose(out_p0.width_inches, out_im_w)
-    assert isclose(out_p0.height_inches, out_im_h)
-
-
-def test_image_to_pdf(spoof_tesseract_noop, resources, outpdf):
-    check_ocrmypdf(
-        resources / 'crom.png', outpdf, '--image-dpi', '200', env=spoof_tesseract_noop
-    )
-
-
 def test_jbig2_passthrough(spoof_tesseract_cache, resources, outpdf):
     out = check_ocrmypdf(
         resources / 'jbig2.pdf',
@@ -556,19 +387,6 @@ def test_linearized_pdf_and_indirect_object(spoof_tesseract_noop, resources, out
     check_ocrmypdf(resources / 'epson.pdf', outpdf, env=spoof_tesseract_noop)
 
 
-def test_ghostscript_pdfa_failure(spoof_no_tess_no_pdfa, resources, outpdf):
-    p, out, err = run_ocrmypdf(
-        resources / 'ccitt.pdf', outpdf, env=spoof_no_tess_no_pdfa
-    )
-    assert (
-        p.returncode == ExitCode.pdfa_conversion_failed
-    ), "Unexpected return when PDF/A fails"
-
-
-def test_ghostscript_feature_elision(spoof_no_tess_pdfa_warning, resources, outpdf):
-    check_ocrmypdf(resources / 'ccitt.pdf', outpdf, env=spoof_no_tess_pdfa_warning)
-
-
 def test_very_high_dpi(spoof_tesseract_cache, resources, outpdf):
     "Checks for a Decimal quantize error with high DPI, etc"
     check_ocrmypdf(resources / '2400dpi.pdf', outpdf, env=spoof_tesseract_cache)
@@ -586,7 +404,7 @@ def test_overlay(spoof_tesseract_noop, resources, outpdf):
 
 
 def test_destination_not_writable(spoof_tesseract_noop, resources, outdir):
-    if os.getuid() == 0 or os.geteuid() == 0:
+    if os.name != 'nt' and (os.getuid() == 0 or os.geteuid() == 0):
         pytest.xfail(reason="root can write to anything")
     protected_file = outdir / 'protected.pdf'
     protected_file.touch()
@@ -609,27 +427,16 @@ language_model_penalty_non_freq_dict_word 0
         )
 
     check_ocrmypdf(
-        resources / 'ccitt.pdf', outdir / 'out.pdf', '--tesseract-config', cfg_file
+        resources / '3small.pdf',
+        outdir / 'out.pdf',
+        '--tesseract-config',
+        cfg_file,
+        '--pages',
+        '1',
     )
 
 
 @pytest.mark.slow  # This test sometimes times out in CI
-@pytest.mark.parametrize('renderer', RENDERERS)
-def test_tesseract_config_notfound(renderer, resources, outdir):
-    cfg_file = outdir / 'nofile.cfg'
-
-    p, out, err = run_ocrmypdf(
-        resources / 'ccitt.pdf',
-        outdir / 'out.pdf',
-        '--pdf-renderer',
-        renderer,
-        '--tesseract-config',
-        cfg_file,
-    )
-    assert "Can't open" in err, "No error message about missing config file"
-    assert p.returncode == ExitCode.ok, err
-
-
 @pytest.mark.parametrize('renderer', RENDERERS)
 def test_tesseract_config_invalid(renderer, resources, outdir):
     cfg_file = outdir / 'test.cfg'
@@ -648,7 +455,10 @@ THIS FILE IS INVALID
         '--tesseract-config',
         cfg_file,
     )
-    assert "parameter not found" in err.lower(), "No error message"
+    assert (
+        "parameter not found" in err.lower()
+        or "error occurred while parsing" in err.lower()
+    ), "No error message"
     assert p.returncode == ExitCode.invalid_config
 
 
@@ -684,7 +494,7 @@ def test_pagesize_consistency(renderer, resources, outpdf):
 
     first_page_dimensions = pytest.helpers.first_page_dimensions
 
-    infile = resources / 'linn.pdf'
+    infile = resources / '3small.pdf'
 
     before_dims = first_page_dimensions(infile)
 
@@ -697,12 +507,14 @@ def test_pagesize_consistency(renderer, resources, outpdf):
         '--deskew',
         '--remove-background',
         '--clean-final' if pytest.helpers.have_unpaper() else None,
+        '--pages',
+        '1',
     )
 
     after_dims = first_page_dimensions(outpdf)
 
-    assert isclose(before_dims[0], after_dims[0])
-    assert isclose(before_dims[1], after_dims[1])
+    assert isclose(before_dims[0], after_dims[0], rel_tol=1e-4)
+    assert isclose(before_dims[1], after_dims[1], rel_tol=1e-4)
 
 
 def test_skip_big_with_no_images(spoof_tesseract_noop, resources, outpdf):
@@ -716,22 +528,6 @@ def test_skip_big_with_no_images(spoof_tesseract_noop, resources, outpdf):
     )
 
 
-def test_gs_render_failure(spoof_no_tess_gs_render_fail, resources, outpdf):
-    p, out, err = run_ocrmypdf(
-        resources / 'blank.pdf', outpdf, env=spoof_no_tess_gs_render_fail
-    )
-    print(err)
-    assert p.returncode == ExitCode.child_process_error
-
-
-def test_gs_raster_failure(spoof_no_tess_gs_raster_fail, resources, outpdf):
-    p, out, err = run_ocrmypdf(
-        resources / 'ccitt.pdf', outpdf, env=spoof_no_tess_gs_raster_fail
-    )
-    print(err)
-    assert p.returncode == ExitCode.child_process_error
-
-
 @pytest.mark.skipif(
     '8.0.0' <= qpdf.version() <= '8.0.1',
     reason="qpdf regression on pages with no contents",
@@ -860,7 +656,7 @@ def test_compression_changed(
 def test_sidecar_pagecount(spoof_tesseract_cache, resources, outpdf):
     sidecar = outpdf.with_suffix('.txt')
     check_ocrmypdf(
-        resources / 'multipage.pdf',
+        resources / '3small.pdf',
         outpdf,
         '--skip-text',
         '--sidecar',
@@ -868,10 +664,10 @@ def test_sidecar_pagecount(spoof_tesseract_cache, resources, outpdf):
         env=spoof_tesseract_cache,
     )
 
-    pdfinfo = PdfInfo(resources / 'multipage.pdf')
+    pdfinfo = PdfInfo(resources / '3small.pdf')
     num_pages = len(pdfinfo)
 
-    with open(sidecar, 'r') as f:
+    with open(sidecar, 'r', encoding='utf-8') as f:
         ocr_text = f.read()
 
     # There should a formfeed between each pair of pages, so the count of
@@ -887,7 +683,7 @@ def test_sidecar_nonempty(spoof_tesseract_cache, resources, outpdf):
         resources / 'ccitt.pdf', outpdf, '--sidecar', sidecar, env=spoof_tesseract_cache
     )
 
-    with open(sidecar, 'r') as f:
+    with open(sidecar, 'r', encoding='utf-8') as f:
         ocr_text = f.read()
     assert 'the' in ocr_text
 
@@ -924,17 +720,18 @@ def test_decompression_bomb(resources, outpdf):
 
 
 def test_text_curves(spoof_tesseract_noop, resources, outpdf):
-    check_ocrmypdf(resources / 'vector.pdf', outpdf, env=spoof_tesseract_noop)
+    with patch('ocrmypdf._pipeline.VECTOR_PAGE_DPI', 100):
+        check_ocrmypdf(resources / 'vector.pdf', outpdf, env=spoof_tesseract_noop)
 
-    info = PdfInfo(outpdf)
-    assert len(info.pages[0].images) == 0, "added images to the vector PDF"
+        info = PdfInfo(outpdf)
+        assert len(info.pages[0].images) == 0, "added images to the vector PDF"
 
-    check_ocrmypdf(
-        resources / 'vector.pdf', outpdf, '--force-ocr', env=spoof_tesseract_noop
-    )
+        check_ocrmypdf(
+            resources / 'vector.pdf', outpdf, '--force-ocr', env=spoof_tesseract_noop
+        )
 
-    info = PdfInfo(outpdf)
-    assert len(info.pages[0].images) != 0, "force did not rasterize"
+        info = PdfInfo(outpdf)
+        assert len(info.pages[0].images) != 0, "force did not rasterize"
 
 
 def test_output_is_dir(spoof_tesseract_noop, resources, outdir):
@@ -945,6 +742,7 @@ def test_output_is_dir(spoof_tesseract_noop, resources, outdir):
     assert 'is not a writable file' in err
 
 
+@pytest.mark.skipif(os.name == 'nt', reason="symlink needs admin permissions")
 def test_output_is_symlink(spoof_tesseract_noop, resources, outdir):
     sym = Path(outdir / 'this_is_a_symlink')
     sym.symlink_to(outdir / 'out.pdf')
