@@ -17,21 +17,22 @@
 
 
 import datetime
-from datetime import timezone
 import logging
 import mmap
+import os
+from datetime import timezone
 from os import fspath
 from pathlib import Path
 from shutil import copyfile, move
 from unittest.mock import MagicMock, patch
 
-import pytest
-
 import pikepdf
+import pytest
+from pikepdf.models.metadata import decode_pdf_date
+
 from ocrmypdf._jobcontext import PDFContext
 from ocrmypdf.exceptions import ExitCode
 from ocrmypdf.pdfa import SRGB_ICC_PROFILE, file_claims_pdfa, generate_pdfa_ps
-from pikepdf.models.metadata import decode_pdf_date
 
 try:
     import fitz
@@ -330,10 +331,8 @@ def test_prevent_gs_invalid_xml(resources, outdir):
         str(outdir / 'layers.rendered.pdf'), str(outdir / 'pdfa.ps'), context
     )
 
-    with open(outdir / 'pdfa.pdf', 'rb') as f:
-        with mmap.mmap(
-            f.fileno(), 0, flags=mmap.MAP_PRIVATE, prot=mmap.PROT_READ
-        ) as mm:
+    with open(outdir / 'pdfa.pdf', 'r+b') as f:
+        with mmap.mmap(f.fileno(), 0) as mm:
             # Since the XML may be invalid, we scan instead of actually feeding it
             # to a parser.
             XMP_MAGIC = b'W5M0MpCehiHzreSzNTczkc9d'
