@@ -20,8 +20,8 @@ from unittest.mock import patch
 
 import pytest
 
-from ocrmypdf.cli import parser
 from ocrmypdf._validation import check_options
+from ocrmypdf.cli import parser
 from ocrmypdf.exceptions import ExitCode, MissingDependencyError
 from ocrmypdf.exec import unpaper
 
@@ -43,7 +43,7 @@ def have_unpaper():
         return True
 
 
-@pytest.fixture(scope="session")
+@pytest.fixture
 def spoof_unpaper_oldversion(tmp_path_factory):
     return spoof(tmp_path_factory, unpaper="unpaper_oldversion.py")
 
